@@ -93,11 +93,12 @@ sub run {
     }
     
     my @args = $found ? $found : @files;
+    @args    = sort @args;
 
     local $ENV{HARNESS_TIMER};
 
     my $prove = App::Prove->new;
-    $prove->process_args( @args );
+    $prove->process_args( '--norc', @args );
     my ($stdout, $stderr, @result) = capture {
         $prove->run;
     };
@@ -119,7 +120,7 @@ Mojolicious::Plugin::Prove::Controller
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
